@@ -71,7 +71,7 @@ class Repository(object):
 
 	@property
 	def remote(self) -> dict[Remote]:
-		remotes = self.execute('git remote')[0]
+		remotes = self.execute('git remote -v')[0]
 		return dict((rem.user, rem) for rem in [Remote(repository=self, remoteString=r) for r in remotes.split('\n')])
 
 
@@ -325,7 +325,7 @@ class Status(object):
 
 class Remote(object):
 
-	def __init__(self, repository: Repository, name: str = None, url: str = None, user: str = None, remoteString: str = None):
+	def __init__(self, repository: Repository, name: str = None, url: str = None, user: str = None, type: str = '', remoteString: str = None):
 		"""
 		:param name:
 		:param url:
@@ -336,9 +336,11 @@ class Remote(object):
 		self.name = name
 		self.url = url
 		self.user = user
+		self.type = type
 
 		if remoteString is not None:
-			self.name, dummy, self.url, direction = remoteString.split(' ')
+			rest, self.type = remoteString.split(' ')
+			self.name, self.url = rest.split('\t')
 		if self.user is None:
 			match = re.search('github.com/(.+?)/', self.url)
 			if match:
@@ -350,4 +352,8 @@ class Remote(object):
 		:param branch:
 		:return:
 		"""
-		return subprocess.run(f'git -C {str(self.repository.path)} rev-list --count {self.name}/{branch}..HEAD').stdout.strip()[0]
+		subprocess.run(f'git -C {str(self.repository.path)} fetch', shell=True)
+		proc = subprocess.run(f'git -C {str(self.repository.path)} rev-list --count {self.name}/{branch}..HEAD', shell=True)
+		if proc.stdout is None:
+			return proc.stderr
+		return proc.stdout.strip()[0]
